import { Component } from '@angular/core';
import { LinkService } from '../service/link.service';
import { RecordModel } from 'pocketbase';
import { NavbarComponent } from '../navbar/navbar.component';
import { Router, RouterLink } from '@angular/router';
import { MatRow, MatTableModule } from '@angular/material/table';
import { MatCardModule } from '@angular/material/card';
import { Link } from '../models/link';
import { MatButtonModule } from '@angular/material/button';

@Component({
  selector: 'app-dashboard',
  imports: [NavbarComponent, MatTableModule, MatCardModule, MatButtonModule],
  templateUrl: './dashboard.component.html',
  styleUrl: './dashboard.component.css'
})
export class DashboardComponent {
  public links: Link[] = [];
  displayedColumns: string[] = ['id', 'name', 'link', 'shortLink', 'actions'];

  constructor(private linkService: LinkService, private router: Router) { };

  copyLink(id: string) {
    navigator.clipboard.writeText(this.getShortLink(id));
  }

  getShortLink(id: string): string {
    return window.location.hostname + '/' + id;
  }

  ngOnInit(): void {
    this.linkService.getLinks().then(links => {
      this.links = links;
    });
  }

  createLink() {
    this.router.navigate(['create-link']);
  }

  deleteLink(id: string) {
    this.linkService.deleteLink(id); // TODO Check if something went wrong
    this.links = this.links.filter(link => {
      return link.id != id;
    });
  }
}
